@@ -1,11 +1,10 @@
 #[cfg(not(feature = "library"))]
 use cosmwasm_std::entry_point;
 use cosmwasm_std::{
-    attr, coins, from_slice, to_binary, Addr, BankMsg, Binary, Deps, DepsMut, Env, MessageInfo,
-    Order, Response, StdResult, Storage, SubMsg, Uint128, WasmMsg,
+    coins, from_slice, to_binary, Addr, BankMsg, Binary, Deps, DepsMut, Env, MessageInfo, Order,
+    Response, StdResult, Storage, SubMsg, Uint128, WasmMsg,
 };
 
-use cw0::{maybe_addr, NativeBalance};
 use cw2::set_contract_version;
 use cw20::{Balance, Cw20CoinVerified, Cw20ExecuteMsg, Cw20ReceiveMsg, Denom};
 use cw4::{
@@ -13,6 +12,7 @@ use cw4::{
     TotalWeightResponse,
 };
 use cw_storage_plus::Bound;
+use cw_utils::{maybe_addr, NativeBalance};
 
 use crate::error::ContractError;
 use crate::msg::{ExecuteMsg, InstantiateMsg, QueryMsg, ReceiveMsg, StakedResponse};
@@ -114,17 +114,11 @@ pub fn execute_bond(
         env.block.height,
     )?;
 
-    let attributes = vec![
-        attr("action", "bond"),
-        attr("amount", amount),
-        attr("sender", sender),
-    ];
-    Ok(Response {
-        messages,
-        attributes,
-        events: vec![],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_submessages(messages)
+        .add_attribute("action", "bond")
+        .add_attribute("amount", amount)
+        .add_attribute("sender", sender))
 }
 
 pub fn execute_receive(
@@ -178,17 +172,11 @@ pub fn execute_unbond(
         env.block.height,
     )?;
 
-    let attributes = vec![
-        attr("action", "unbond"),
-        attr("amount", amount),
-        attr("sender", info.sender),
-    ];
-    Ok(Response {
-        messages,
-        attributes,
-        events: vec![],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_submessages(messages)
+        .add_attribute("action", "unbond")
+        .add_attribute("amount", amount)
+        .add_attribute("sender", info.sender))
 }
 
 pub fn must_pay_funds(balance: &NativeBalance, denom: &str) -> Result<Uint128, ContractError> {
@@ -287,17 +275,11 @@ pub fn execute_claim(
         }
     };
 
-    let attributes = vec![
-        attr("action", "claim"),
-        attr("tokens", amount_str),
-        attr("sender", info.sender),
-    ];
-    Ok(Response {
-        messages: vec![message],
-        attributes,
-        events: vec![],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_submessage(message)
+        .add_attribute("action", "claim")
+        .add_attribute("tokens", amount_str)
+        .add_attribute("sender", info.sender))
 }
 
 #[inline]
@@ -359,19 +341,18 @@ fn list_members(
     let addr = maybe_addr(deps.api, start_after)?;
     let start = addr.map(|addr| Bound::exclusive(addr.as_ref()));
 
-    let members: StdResult<Vec<_>> = MEMBERS
+    let members = MEMBERS
         .range(deps.storage, start, None, Order::Ascending)
         .take(limit)
         .map(|item| {
-            let (key, weight) = item?;
-            Ok(Member {
-                addr: String::from_utf8(key)?,
+            item.map(|(addr, weight)| Member {
+                addr: addr.into(),
                 weight,
             })
         })
-        .collect();
+        .collect::<StdResult<_>>()?;
 
-    Ok(MemberListResponse { members: members? })
+    Ok(MemberListResponse { members })
 }
 
 #[cfg(test)]
@@ -380,10 +361,10 @@ mod tests {
     use cosmwasm_std::{
         coin, from_slice, CosmosMsg, OverflowError, OverflowOperation, StdError, Storage,
     };
-    use cw0::Duration;
     use cw20::Denom;
     use cw4::{member_key, TOTAL_KEY};
     use cw_controllers::{AdminError, Claim, HookError};
+    use cw_utils::Duration;
 
     use crate::error::ContractError;
 
@@ -484,7 +465,7 @@ mod tests {
 
     #[test]
     fn proper_instantiation() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
 
         // it worked, let's query the state
@@ -554,7 +535,7 @@ mod tests {
 
     #[test]
     fn bond_stake_adds_membership() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
         let height = mock_env().block.height;
 
@@ -584,7 +565,7 @@ mod tests {
 
     #[test]
     fn unbond_stake_update_membership() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
         let height = mock_env().block.height;
 
@@ -628,7 +609,7 @@ mod tests {
 
     #[test]
     fn cw20_token_bond() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         cw20_instantiate(deps.as_mut(), Duration::Height(2000));
 
         // Assert original weights
@@ -647,7 +628,7 @@ mod tests {
         let unbonding_period: u64 = 50;
         let unbond_height: u64 = 10;
 
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         let unbonding = Duration::Height(unbonding_period);
         cw20_instantiate(deps.as_mut(), unbonding);
 
@@ -704,7 +685,7 @@ mod tests {
     #[test]
     fn raw_queries_work() {
         // add will over-write and remove have no effect
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
         // Set values as (11, 6, None)
         bond(deps.as_mut(), 11_000, 6_000, 0, 1);
@@ -730,7 +711,7 @@ mod tests {
 
     #[test]
     fn unbond_claim_workflow() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
 
         // create some data
@@ -865,7 +846,7 @@ mod tests {
     #[test]
     fn add_remove_hooks() {
         // add will over-write and remove have no effect
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
 
         let hooks = HOOKS.query_hooks(deps.as_ref()).unwrap();
@@ -933,7 +914,7 @@ mod tests {
 
     #[test]
     fn hooks_fire() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
 
         let hooks = HOOKS.query_hooks(deps.as_ref()).unwrap();
@@ -987,7 +968,7 @@ mod tests {
 
     #[test]
     fn only_bond_valid_coins() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
 
         // cannot bond with 0 coins
@@ -1014,7 +995,7 @@ mod tests {
     #[test]
     fn ensure_bonding_edge_cases() {
         // use min_bond 0, tokens_per_weight 500
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         do_instantiate(
             deps.as_mut(),
             Uint128::new(100),
